@@ -114,7 +114,9 @@ def _render_template(template_name, **kwargs):
         config.update((var, getattr(config_module, var, None))
                       for var in config_module.__dict__
                       if var not in MAKO_INTERNALS)
-    known_keys = set(config) | {'module', 'modules', 'http_server', 'external_links'}  # deprecated
+    known_keys = (set(config)
+                  | {'docformat'}  # Feature. https://github.com/pdoc3/pdoc/issues/169
+                  | {'module', 'modules', 'http_server', 'external_links'})  # deprecated
     invalid_keys = {k: v for k, v in kwargs.items() if k not in known_keys}
     if invalid_keys:
         warn('Unknown configuration variables (not in config.mako): {}'.format(invalid_keys))
@@ -136,7 +138,7 @@ def _render_template(template_name, **kwargs):
         raise
 
 
-def html(module_name, docfilter=None, reload=False, **kwargs) -> str:
+def html(module_name, docfilter=None, reload=False, skip_errors=False, **kwargs) -> str:
     """
     Returns the documentation for the module `module_name` in HTML
     format. The module must be a module or an importable string.
@@ -146,12 +148,13 @@ def html(module_name, docfilter=None, reload=False, **kwargs) -> str:
     that takes a single argument (a documentation object) and returns
     `True` or `False`. If `False`, that object will not be documented.
     """
-    mod = Module(import_module(module_name, reload=reload), docfilter=docfilter)
+    mod = Module(import_module(module_name, reload=reload),
+                 docfilter=docfilter, skip_errors=skip_errors)
     link_inheritance()
     return mod.html(**kwargs)
 
 
-def text(module_name, docfilter=None, reload=False, **kwargs) -> str:
+def text(module_name, docfilter=None, reload=False, skip_errors=False, **kwargs) -> str:
     """
     Returns the documentation for the module `module_name` in plain
     text format suitable for viewing on a terminal.
@@ -162,7 +165,8 @@ def text(module_name, docfilter=None, reload=False, **kwargs) -> str:
     that takes a single argument (a documentation object) and returns
     `True` or `False`. If `False`, that object will not be documented.
     """
-    mod = Module(import_module(module_name, reload=reload), docfilter=docfilter)
+    mod = Module(import_module(module_name, reload=reload),
+                 docfilter=docfilter, skip_errors=skip_errors)
     link_inheritance()
     return mod.text(**kwargs)
 
@@ -195,7 +199,8 @@ def import_module(module: Union[str, ModuleType],
             try:
                 module = importlib.import_module(module_path)
             except Exception as e:
-                raise ImportError('Error importing {!r}: {}'.format(module, e))
+                raise ImportError('Error importing {!r}: {}: {}'
+                                  .format(module, e.__class__.__name__, e))
 
     assert inspect.ismodule(module)
     # If this is pdoc itself, return without reloading. Otherwise later
@@ -542,10 +547,12 @@ class Module(Doc):
         it was imported from. It is always an absolute import path.
         """
 
-    __slots__ = ('supermodule', 'doc', '_context', '_is_inheritance_linked')
+    __slots__ = ('supermodule', 'doc', '_context', '_is_inheritance_linked',
+                 '_skipped_submodules')
 
     def __init__(self, module: Union[ModuleType, str], *, docfilter: Callable[[Doc], bool] = None,
-                 supermodule: 'Module' = None, context: Context = None):
+                 supermodule: 'Module' = None, context: Context = None,
+                 skip_errors: bool = False):
         """
         Creates a `Module` documentation object given the actual
         module Python object.
@@ -558,6 +565,10 @@ class Module(Doc):
 
         `context` is an instance of `pdoc.Context`. If `None` a
         global context object will be used.
+
+        If `skip_errors` is `True` and an unimportable, erroneous
+        submodule is encountered, a warning will be issued instead
+        of raising an exception.
         """
         if isinstance(module, str):
             module = import_module(module)
@@ -583,6 +594,8 @@ class Module(Doc):
         self._is_inheritance_linked = False
         """Re-entry guard for `pdoc.Module._link_inheritance()`."""
 
+        self._skipped_submodules = set()
+
         var_docstrings, _ = _pep224_docstrings(self)
 
         # Populate self.doc with this module's public members
@@ -643,13 +656,22 @@ class Module(Doc):
                 if not _is_public(root) and not _is_whitelisted(root, self):
                     continue
                 if _is_blacklisted(root, self):
+                    self._skipped_submodules.add(root)
                     continue
 
                 assert self.refname == self.name
                 fullname = "%s.%s" % (self.name, root)
-                self.doc[root] = m = Module(import_module(fullname),
-                                            docfilter=docfilter, supermodule=self,
-                                            context=self._context)
+                try:
+                    m = Module(import_module(fullname),
+                               docfilter=docfilter, supermodule=self,
+                               context=self._context, skip_errors=skip_errors)
+                except Exception as ex:
+                    if skip_errors:
+                        warn(str(ex), Module.ImportWarning)
+                        continue
+                    raise
+
+                self.doc[root] = m
                 # Skip empty namespace packages because they may
                 # as well be other auxiliary directories
                 if m.is_namespace and not m.doc:
@@ -671,6 +693,14 @@ class Module(Doc):
                 self._context.update((obj.refname, obj)
                                      for obj in docobj.doc.values())
 
+    class ImportWarning(UserWarning):
+        """
+        Our custom import warning because the builtin is ignored by default.
+        https://docs.python.org/3/library/warnings.html#default-warning-filter
+        """
+
+    __pdoc__['Module.ImportWarning'] = False
+
     @property
     def __pdoc__(self):
         """This module's __pdoc__ dict, or an empty dict if none."""
@@ -701,6 +731,9 @@ class Module(Doc):
                          'use `__pdoc__[key] = False` '
                          '(key: {!r}, module: {!r}).'.format(name, self.name))
 
+                if name in self._skipped_submodules:
+                    continue
+
                 if (not name.endswith('.__init__') and
                         name not in self.doc and refname not in self._context):
                     warn('__pdoc__-overriden key {!r} does not exist '
@@ -1247,6 +1280,7 @@ class Function(Doc):
 
         params = []
         kw_only = False
+        pos_only = False
         EMPTY = inspect.Parameter.empty
 
         if link:
@@ -1257,6 +1291,12 @@ class Function(Doc):
             if not _is_public(p.name) and p.default is not EMPTY:
                 continue
 
+            if p.kind == p.POSITIONAL_ONLY:
+                pos_only = True
+            elif pos_only:
+                params.append("/")
+                pos_only = False
+
             if p.kind == p.VAR_POSITIONAL:
                 kw_only = True
             if p.kind == p.KEYWORD_ONLY and not kw_only:
@@ -1268,22 +1308,29 @@ class Function(Doc):
             if not annotate:
                 p = p.replace(annotation=EMPTY)
 
-            s = str(p)
+            formatted = p.name
             if p.annotation is not EMPTY:
-                if sys.version_info < (3, 7):
-                    # PEP8-normalize whitespace
-                    s = re.sub(r'(?<!\s)=(?!\s)', ' = ', re.sub(r':(?!\s)', ': ', s, 1), 1)
+                annotation = inspect.formatannotation(p.annotation).replace(' ', '\N{NBSP}')
                 # "Eval" forward-declarations (typing string literals)
                 if isinstance(p.annotation, str):
-                    s = s.replace("'%s'" % p.annotation, p.annotation, 1)
-                s = s.replace(' ', '\N{NBSP}')  # prevent improper line breaking
-
+                    annotation = annotation.strip("'")
                 if link:
-                    annotation = inspect.formatannotation(p.annotation)
-                    linked_annotation = re.sub(r'[\w\.]+', _linkify, annotation)
-                    s = linked_annotation.join(s.rsplit(annotation, 1))  # "rreplace" once
+                    annotation = re.sub(r'[\w\.]+', _linkify, annotation)
+                formatted += ':\N{NBSP}' + annotation
+            if p.default is not EMPTY:
+                if p.annotation is not EMPTY:
+                    formatted += '\N{NBSP}=\N{NBSP}' + repr(p.default)
+                else:
+                    formatted += '=' + repr(p.default)
+            if p.kind == p.VAR_POSITIONAL:
+                formatted = '*' + formatted
+            elif p.kind == p.VAR_KEYWORD:
+                formatted = '**' + formatted
 
-            params.append(s)
+            params.append(formatted)
+
+        if pos_only:
+            params.append("/")
 
         return params
 
