@@ -245,7 +245,7 @@ class _ToMarkdown:
             section = section.title()
             if section in ('Args', 'Attributes'):
                 body = re.compile(
-                    r'^([\w*]+)(?: \(([\w.,=\[\] ]+)\))?: '
+                    r'^([\w*]+)(?: \(([\w.,=\[\] -]+)\))?: '
                     r'((?:.*)(?:\n(?: {2,}.*|$))*)', re.MULTILINE).sub(
                     lambda m: _ToMarkdown._deflist(*_ToMarkdown._fix_indent(*m.groups())),
                     inspect.cleandoc('\n' + body)
@@ -257,7 +257,9 @@ class _ToMarkdown:
                     lambda m: _ToMarkdown._deflist(*_ToMarkdown._fix_indent(*m.groups())),
                     inspect.cleandoc('\n' + body)
                 )
-            return '\n{}\n-----\n{}'.format(section, body)
+            # Convert into markdown sections. End underlines with '='
+            # to avoid matching and re-processing as Numpy sections.
+            return '\n{}\n-----=\n{}'.format(section, body)
 
         text = re.compile(r'^([A-Z]\w+):$\n'
                           r'((?:\n?(?: {2,}.*|$))+)', re.MULTILINE).sub(googledoc_sections, text)
@@ -331,7 +333,7 @@ class _ToMarkdown:
         start_after = options.get('start-after')
         end_before = options.get('end-before')
 
-        with open(os.path.join(os.path.dirname(module.obj.__file__), path),
+        with open(os.path.normpath(os.path.join(os.path.dirname(module.obj.__file__), path)),
                   encoding='utf-8') as f:
             text = ''.join(list(f)[start_line:end_line])
 
@@ -346,6 +348,8 @@ class _ToMarkdown:
     def _directive_opts(text: str) -> dict:
         return dict(re.findall(r'^ *:([^:]+): *(.*)', text, re.MULTILINE))
 
+    DOCTESTS_RE = re.compile(r'^(?:>>> .*)(?:\n.+)*', re.MULTILINE)
+
     @staticmethod
     def doctests(text):
         """
@@ -353,7 +357,7 @@ class _ToMarkdown:
         doctest blocks so they render as Python code.
         """
         with _fenced_code_blocks_hidden(text) as result:
-            result[0] = re.compile(r'^(?:>>> .*)(?:\n.+)*', re.MULTILINE).sub(
+            result[0] = _ToMarkdown.DOCTESTS_RE.sub(
                 lambda match: '```python\n' + match.group() + '\n```\n', result[0])
         text = result[0]
         return text
@@ -361,9 +365,25 @@ class _ToMarkdown:
     @staticmethod
     def raw_urls(text):
         """Wrap URLs in Python-Markdown-compatible <angle brackets>."""
+        pattern = re.compile(r"""
+            (?P<code_span>                   # matches whole code span
+                (?<!`)(?P<fence>`+)(?!`)     # a string of backticks
+                .*?
+                (?<!`)(?P=fence)(?!`))
+            |
+            (?P<markdown_link>\[.*?\]\(.*\))  # matches whole inline link
+            |
+            (?<![<\"\'])                     # does not start with <, ", '
+            (?P<url>(?:http|ftp)s?://        # url with protocol
+                [^>\s()]+                    # url part before any (, )
+                (?:\([^>\s)]*\))*            # optionally url part within parentheses
+                [^>\s)]*                     # url part after any )
+            )""", re.VERBOSE)
+
         with _fenced_code_blocks_hidden(text) as result:
-            result[0] = re.sub(r'(?<![<"\'])(\s*)((?:http|ftp)s?://[^>)\s]+)(\s*)',
-                               r'\1<\2>\3', result[0])
+            result[0] = pattern.sub(
+                lambda m: ('<' + m.group('url') + '>') if m.group('url') else m.group(),
+                result[0])
         text = result[0]
         return text
 
@@ -385,12 +405,13 @@ class _MathPattern(InlineProcessor):
         return wrapper, m.start(0), m.end(0)
 
 
-def to_html(text: str, docformat: str = 'numpy,google', *,
+def to_html(text: str, *,
+            docformat: str = None,
             module: pdoc.Module = None, link: Callable[..., str] = None,
             latex_math: bool = False):
     """
-    Returns HTML of `text` interpreted as `docformat`.
-    By default, Numpydoc and Google-style docstrings are assumed,
+    Returns HTML of `text` interpreted as `docformat`. `__docformat__` is respected
+    if present, otherwise Numpydoc and Google-style docstrings are assumed,
     as well as pure Markdown.
 
     `module` should be the documented module (so the references can be
@@ -414,13 +435,16 @@ def to_markdown(text: str, *,
                 module: pdoc.Module = None, link: Callable[..., str] = None):
     """
     Returns `text`, assumed to be a docstring in `docformat`, converted to markdown.
+    `__docformat__` is respected
+    if present, otherwise Numpydoc and Google-style docstrings are assumed,
+    as well as pure Markdown.
 
     `module` should be the documented module (so the references can be
     resolved) and `link` is the hyperlinking function like the one in the
     example template.
     """
-    if docformat is None:
-        docformat = getattr(getattr(module, 'obj', None), '__docformat__', 'numpy,google ')
+    if not docformat:
+        docformat = str(getattr(getattr(module, 'obj', None), '__docformat__', 'numpy,google '))
         docformat, *_ = docformat.lower().split()
     if not (set(docformat.split(',')) & {'', 'numpy', 'google'}):
         warn('__docformat__ value {!r} in module {!r} not supported. '
@@ -511,6 +535,9 @@ def extract_toc(text: str):
     """
     Returns HTML Table of Contents containing markdown titles in `text`.
     """
+    with _fenced_code_blocks_hidden(text) as result:
+        result[0] = _ToMarkdown.DOCTESTS_RE.sub('', result[0])
+    text = result[0]
     toc, _ = _md.reset().convert('[TOC]\n\n@CUT@\n\n' + text).split('@CUT@', 1)
     if toc.endswith('<p>'):  # CUT was put into its own paragraph
         toc = toc[:-3].rstrip()
@@ -573,6 +600,7 @@ def _git_project_root():
                 break
         except (subprocess.CalledProcessError, OSError):
             pass
+    path = os.path.normpath(path)
     return path
 
 
@@ -587,7 +615,7 @@ def _project_relative_path(absolute_path):
     for prefix_path in (_git_project_root() or os.getcwd(),
                         get_python_lib()):
         common_path = os.path.commonpath([prefix_path, absolute_path])
-        if common_path == prefix_path:
+        if os.path.samefile(common_path, prefix_path):
             # absolute_path is a descendant of prefix_path
             return os.path.relpath(absolute_path, prefix_path)
     raise RuntimeError(
