@@ -67,7 +67,8 @@ def run(*args, _check=True, **kwargs) -> int:
 
 @contextmanager
 def run_html(*args, **kwargs):
-    with temp_dir() as path:
+    with temp_dir() as path, \
+            redirect_streams():
         run(*args, html=None, output_dir=path, **kwargs)
         with chdir(path):
             yield
@@ -228,6 +229,12 @@ class CliTest(unittest.TestCase):
                 ],
             )
 
+    def test_docformat(self):
+        with self.assertWarns(UserWarning) as cm,\
+                run_html(EXAMPLE_MODULE, config='docformat="restructuredtext"'):
+            self._basic_html_assertions()
+        self.assertIn('numpy', cm.warning.args[0])
+
     def test_html_no_source(self):
         with self.assertWarns(DeprecationWarning),\
                 run_html(EXAMPLE_MODULE, html_no_source=None):
@@ -355,8 +362,9 @@ class CliTest(unittest.TestCase):
         self.assertIn('pdoc3.github.io', out)
         self.assertIn('pandoc', err)
 
-        self.assertIn(str(inspect.signature(pdoc.Doc.__init__)).replace('self, ', ''),
-                      out)
+        pdoc_Doc_params = str(inspect.signature(pdoc.Doc.__init__)).replace('self, ', '')
+        self.assertIn(pdoc_Doc_params.replace(' ', ''),
+                      out.replace('>', '').replace('\n', '').replace(' ', ''))
 
     def test_config(self):
         with run_html(EXAMPLE_MODULE, config='link_prefix="/foobar/"'):
@@ -364,7 +372,8 @@ class CliTest(unittest.TestCase):
             self._check_files(['/foobar/' + EXAMPLE_MODULE])
 
     def test_output_text(self):
-        with temp_dir() as path:
+        with temp_dir() as path, \
+                redirect_streams():
             run(EXAMPLE_MODULE, output_dir=path)
             with chdir(path):
                 self._basic_html_assertions([file.replace('.html', '.md')
@@ -382,6 +391,13 @@ class CliTest(unittest.TestCase):
             with run_html('.'):
                 self._check_files(())
 
+    def test_skip_errors(self):
+        with chdir(os.path.join(TESTS_BASEDIR, EXAMPLE_MODULE, '_skip_errors')),\
+                redirect_streams(),\
+                self.assertWarns(pdoc.Module.ImportWarning) as cm:
+            run('.', skip_errors=None)
+        self.assertIn('ZeroDivision', cm.warning.args[0])
+
 
 class ApiTest(unittest.TestCase):
     """
@@ -537,6 +553,10 @@ class ApiTest(unittest.TestCase):
         module = pdoc.import_module(EXAMPLE_MODULE + '._exclude_dir')
         with patch.object(module, '__pdoc__', {'downloaded_modules': False}, create=True):
             mod = pdoc.Module(module)
+            # GH-206: https://github.com/pdoc3/pdoc/issues/206
+            with warnings.catch_warnings(record=True) as cm:
+                pdoc.link_inheritance()
+            self.assertEqual(cm, [])
             self.assertNotIn('downloaded_modules', mod.doc)
 
     def test__pdoc__invalid_value(self):
@@ -773,6 +793,13 @@ class ApiTest(unittest.TestCase):
                          ['a:\N{NBSP}int', '*b',
                           "c:\N{NBSP}List[<a href=\"#pdoc.Doc\">Doc</a>]\N{NBSP}=\N{NBSP}[]"])
 
+        # typed, linked, GH-311
+        def f(a: typing.Dict[str, pdoc.Doc]): pass
+
+        func = pdoc.Function('f', mod, f)
+        self.assertEqual(func.params(annotate=True, link=link),
+                         ["a:\N{NBSP}Dict[str,\N{NBSP}<a href=\"#pdoc.Doc\">Doc</a>]"])
+
         # shadowed name
         def f(pdoc: int): pass
         func = pdoc.Function('f', mod, f)
@@ -796,6 +823,15 @@ class ApiTest(unittest.TestCase):
         self.assertEqual(pdoc.Function('get_sample', mod, get_sample).return_annotation(),
                          'Tuple[int,\xa0float]')
 
+    @unittest.skipIf(sys.version_info < (3, 8), "positional-only arguments unsupported in < py3.8")
+    def test_test_Function_params_python38_specific(self):
+        mod = pdoc.Module(pdoc)
+        func = pdoc.Function('f', mod, eval("lambda a, /, b: None"))
+        self.assertEqual(func.params(), ['a', '/', 'b'])
+
+        func = pdoc.Function('f', mod, eval("lambda a, /: None"))
+        self.assertEqual(func.params(), ['a', '/'])
+
     def test_Function_return_annotation(self):
         import typing
 
@@ -840,6 +876,9 @@ class Foo:
             self.assertIsInstance(mod.doc['Foo'].doc['var2'], pdoc.Variable)
             self.assertEqual(mod.doc['Foo'].doc['var2'].type_annotation(), '')  # Won't fix
 
+            self.assertIn('var: str', mod.text())
+            self.assertIn('var: int', mod.text())
+
     @ignore_warnings
     def test_Class_docstring(self):
         class A:
@@ -1041,13 +1080,39 @@ pdoc
         self.assertIn('example_pkg.nonexisting', cm.warning.args[0])
 
     def test_extract_toc(self):
-        text = 'xxx\n\n# Title\n\nfoo\n\n## Subtitle\n\nbar'
+        text = '''xxx
+
+# Title
+
+>>> # doctests skipped
+# doctest output, skipped
+
+## Subtitle
+
+```
+>>> # code skipped
+# skipped
+```
+
+# Title 2
+
+```
+>>> # code skipped
+# skipped
+```
+
+## Subtitle 2
+'''
         expected = '''<div class="toc">
 <ul>
 <li><a href="#title">Title</a><ul>
 <li><a href="#subtitle">Subtitle</a></li>
 </ul>
 </li>
+<li><a href="#title-2">Title 2</a><ul>
+<li><a href="#subtitle-2">Subtitle 2</a></li>
+</ul>
+</li>
 </ul>
 </div>'''
         toc = extract_toc(text)
@@ -1060,6 +1125,7 @@ pdoc
             template='https://github.com/pdoc3/pdoc/blob/{commit}/{path}#L{start_line}-L{end_line}',
             dobj=pdoc.Module(EXAMPLE_MODULE).find_ident('module.foo'),
         )
+        self.assertIsInstance(url, str)
         self.assertRegex(url, r"https://github.com/pdoc3/pdoc/blob/[0-9a-f]{40}"
                               r"/pdoc/test/example_pkg/module.py#L\d+-L\d+")
 
@@ -1164,6 +1230,8 @@ Nomatch:</p>
 <dt><strong><code>arg2</code></strong> :&ensp;<code>List[str]</code>, optional,\
  default=<code>10</code></dt>
 <dd>Text2</dd>
+<dt><strong><code>data</code></strong> :&ensp;<code>array-like object</code></dt>
+<dd>foo</dd>
 </dl>
 <h2 id="args_1">Args</h2>
 <dl>
@@ -1191,6 +1259,9 @@ if only a single item was listed. <code><a>inspect.cleandoc()</a></code>
 somehow stripped the required extra indentation.</dd>
 </dl>
 <h2 id="returns_1">Returns</h2>
+<p>A very special number
+which is the answer of everything.</p>
+<h2 id="returns_2">Returns</h2>
 <dl>
 <dt><code>Dict[int, <a>pdoc.Doc</a>]</code></dt>
 <dd>Description.</dd>
@@ -1324,29 +1395,48 @@ x =</p>'''
 
     def test_urls(self):
         text = """Beautiful Soup
-http://www.foo.bar
-http://www.foo.bar?q="foo"
 <a href="https://travis-ci.org/cs01/pygdbmi"><img src="https://foo" /></a>
 <https://foo.bar>
-
 Work [like this](http://foo/) and [like that].
-
 [like that]: ftp://bar
-
 data:text/plain;base64,SGVsbG8sIFdvcmxkIQ%3D%3D
-
 ```
 http://url.com
-```"""
+```
+[https://google.com](https://google.com)
+[https://en.wikipedia.org/wiki/Orange_(software)](https://en.wikipedia.org/wiki/Orange_(software))
+[Check https://google.com here](https://google.com)
+`https://google.com`
+
+http://www.foo.bar
+http://www.foo.bar?q="foo"
+https://en.wikipedia.org/wiki/Orange_(software)
+(https://google.com)
+(http://foo and http://bar)
+text ``x ` http://foo`` http://bar `http://foo`
+"""
+
         expected = """<p>Beautiful Soup
-<a href="http://www.foo.bar">http://www.foo.bar</a>
-<a href="http://www.foo.bar?q=&quot;foo&quot;">http://www.foo.bar?q="foo"</a>
 <a href="https://travis-ci.org/cs01/pygdbmi"><img src="https://foo" /></a>
-<a href="https://foo.bar">https://foo.bar</a></p>
-<p>Work <a href="http://foo/">like this</a> and <a href="ftp://bar">like that</a>.</p>
+<a href="https://foo.bar">https://foo.bar</a>
+Work <a href="http://foo/">like this</a> and <a href="ftp://bar">like that</a>.</p>
 <p>data:text/plain;base64,SGVsbG8sIFdvcmxkIQ%3D%3D</p>
 <pre><code>http://url.com
-</code></pre>"""
+</code></pre>
+
+<p><a href="https://google.com">https://google.com</a>
+<a href="https://en.wikipedia.org/wiki/Orange_(software)">\
+https://en.wikipedia.org/wiki/Orange_(software)</a>
+<a href="https://google.com">Check https://google.com here</a>
+<code>https://google.com</code></p>
+<p><a href="http://www.foo.bar">http://www.foo.bar</a>
+<a href="http://www.foo.bar?q=&quot;foo&quot;">http://www.foo.bar?q="foo"</a>
+<a href="https://en.wikipedia.org/wiki/Orange_(software)">\
+https://en.wikipedia.org/wiki/Orange_(software)</a>
+(<a href="https://google.com">https://google.com</a>)
+(<a href="http://foo">http://foo</a> and <a href="http://bar">http://bar</a>)
+text <code>x ` http://foo</code> <a href="http://bar">http://bar</a> <code>http://foo</code></p>"""
+
         html = to_html(text)
         self.assertEqual(html, expected)
 
